@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2018 Canonical
+ * Copyright (C) 2011-2019 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1089,8 +1089,6 @@ static HOT timer_info_t *timer_info_find(
 	info->func = strdup(new_info->func);
 	info->ident = strdup(ident);
 	info->kernel_thread = new_info->kernel_thread;
-	info->total_events = new_info->total_events;
-	info->delta_events = new_info->delta_events;
 	info->time_total = new_info->time_total;
 	info->timer = new_info->timer;
 	info->ref_count = 0;
@@ -1507,7 +1505,6 @@ static OPTIMIZE3 void timer_stat_dump(
 					double tick_time = now - sorted->info->cpu_ticks_time;
 					uint32_t tasks = get_proc_cpu_tasks(sorted->info->pid);
 					uint64_t cpu_ticks;
-					uint64_t ticks;
 					uint16_t cpu_rt_prio;
 					int16_t cpu_nice;
 					double cpu;
@@ -1516,7 +1513,8 @@ static OPTIMIZE3 void timer_stat_dump(
 							   &cpu_rt_prio, &cpu_nice);
 
 					if (cpu_ticks && sorted->info->cpu_ticks) {
-						ticks = cpu_ticks - sorted->info->cpu_ticks;
+						uint64_t ticks = cpu_ticks - sorted->info->cpu_ticks;
+
 						cpu = (100.0 * (double)ticks) / (tick_time * (double)clock_tick_rate);
 					} else {
 						cpu = 0.0;
